@@ -44,6 +44,7 @@
 #include "giza-line-style-private.h"
 #include "giza-band-private.h"
 #include "giza-stroke-private.h"
+#include "giza-text-background-private.h"
 #include <giza.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -54,12 +55,9 @@
 #define GIZA_DEFAULT_MARGIN 0
 
 static void _giza_set_prefix (const char *prefix);
-static int id = 0;
+static int _giza_get_internal_id(int devid);
+static int _giza_device_id = 0;
 
-/*
- * NOTE: Should clean up surfaces etc if device open was not successful.
- * Opens a device for drawing to.
- */
 /**
  * Device: giza_open_device
  *
@@ -72,8 +70,8 @@ static int id = 0;
  *  -newPrefix     :- Specifies the default prefix to be used for file names.
  *
  * Return value:
- *  -0 :- if no error has occurred
- *  -1 :- if an error occurred
+ *  -<=0 :- an error has occurred
+ *  -1   :- id of current device
  *
  * Available devices:
  *  -?    :- User selects device
@@ -85,21 +83,52 @@ static int id = 0;
  *  -/vpdf :- Landscape Portable Document Format
  *  -/ps  :- PostScript
  *  -/vps :- Landscape Postscript
+ *
+ *  For hardcopy devices, the device type can also be recognised
+ *  automatically by specifying the filename
+ *  e.g: giza_open_device("plot.png","giza")
+ *
+ * See Also: giza_select_device, giza_get_device_id, giza_close_device, giza_query_device
  */
 int
 giza_open_device (const char *newDeviceName, const char *newPrefix)
 {
+  return giza_open_device_size (newDeviceName, newPrefix, 0., 0., 0);
+}
 
-  if (id != 0) {
-     _giza_warning("giza_open_device", "previous device was not closed");
-     giza_close_device();
-  }
-  id += 1;
-
+/**
+ * Device: giza_open_device_size
+ *
+ * Synopsis: Similar to giza_open_device, but allows one to specify the size of the device
+ *
+ * Input:
+ *  -newDeviceName :- Specifies the type of device to be opened.
+ *                    See below for details.
+ *  -newPrefix     :- Specifies the default prefix to be used for file names.
+ *  -width         :- Width for the newly opened device
+ *  -height        :- Height for the newly opened device
+ *  -units         :- Units in which the width/height of the device are specified
+ *
+ * Units:
+ *  -GIZA_UNITS_DEVICE     :- device coords (i.e. pixels on bitmap devices, points on vector devices)
+ *  -GIZA_UNITS_PIXELS     :- pixels
+ *  -GIZA_UNITS_MM         :- mm
+ *  -GIZA_UNITS_INCHES     :- inches
+ *  Other values cause an error message and are treated as GIZA_UNITS_DEVICE
+ *
+ * See also: giza_open_device
+ */
+int
+giza_open_device_size (const char *newDeviceName, const char *newPrefix, double width, double height, int units)
+{
+  _giza_device_id += 1;
+  id = _giza_get_internal_id(_giza_device_id);
+  
   /* Some general initialisation */
-  Dev.pgNum = 0;
-  Dev.type = GIZA_DEVICE_IV;
-  Dev.defaultBackgroundAlpha = 1.;
+  Dev[id].pgNum = 0;
+  Dev[id].type = GIZA_DEVICE_IV;
+  Dev[id].defaultBackgroundAlpha = 1.;
+  Dev[id].deviceOpen = 1;
   int success = -1;
   giza_set_text_background (-1);
   giza_start_prompting ();
@@ -117,46 +146,46 @@ giza_open_device (const char *newDeviceName, const char *newPrefix)
   /* Determine which type of device to open */
   char firstchar = newDeviceName[0];
   if (firstchar == '?')
-    Dev.type = _giza_prompt_for_device ();
+    Dev[id].type = _giza_prompt_for_device ();
   else
     {
       char *devTypeStr;
       _giza_split_device_string (newDeviceName, &devTypeStr);
-      Dev.type = _giza_device_to_int (devTypeStr);
+      Dev[id].type = _giza_device_to_int (devTypeStr);
     }
 
   /* Determine which driver is required */
-  switch (Dev.type)
+  switch (Dev[id].type)
     {
 #ifdef _GIZA_HAS_XW
     case GIZA_DEVICE_XW:
-      success = _giza_open_device_xw ();
+      success = _giza_open_device_xw (width, height, units);
       break;
 #endif
     case GIZA_DEVICE_PNG:
-      success = _giza_open_device_png ();
+      success = _giza_open_device_png (width, height, units);
       break;
     case GIZA_DEVICE_PDF:
-      success = _giza_open_device_pdf (0);
+      success = _giza_open_device_pdf (width, height, units, 0);
       break;
     case GIZA_DEVICE_VPDF:
-      success = _giza_open_device_pdf(1);
+      success = _giza_open_device_pdf(width, height, units, 1);
       break;
     case GIZA_DEVICE_PS:
-      success = _giza_open_device_ps (0);
+      success = _giza_open_device_ps (width, height, units, 0);
       break;
     case GIZA_DEVICE_VPS:
-      success = _giza_open_device_ps (1);
+      success = _giza_open_device_ps (width, height, units, 1);
       break;
     case GIZA_DEVICE_SVG:
-      success = _giza_open_device_svg (0);
+      success = _giza_open_device_svg (width, height, units, 0);
       break;
     case GIZA_DEVICE_NULL:
-      success = _giza_open_device_null ();
+      success = _giza_open_device_null (width, height, units);
       break;
 #ifdef _GIZA_HAS_EPS
     case GIZA_DEVICE_EPS:
-      success = _giza_open_device_eps (0);
+      success = _giza_open_device_eps (width, height, units, 0);
       break;
 #endif
     case GIZA_DEVICE_IV:
@@ -167,12 +196,13 @@ giza_open_device (const char *newDeviceName, const char *newPrefix)
 
   /* check that the surface was created */
   if (success) {
-     id = id - 1;
+     _giza_device_id = _giza_device_id - 1;
+     id = _giza_get_internal_id(_giza_device_id);
      return -1;
   }
-  /* bind the created surface to our context */
-  context = cairo_create (surface);
-  if (!context)
+  /* bind the created surface to our Dev[id].context */
+  Dev[id].context = cairo_create (Dev[id].surface);
+  if (!Dev[id].context)
     {
       _giza_error ("giza_open_device", "Could not create cairo surface.");
       giza_close_device();
@@ -180,11 +210,12 @@ giza_open_device (const char *newDeviceName, const char *newPrefix)
     }
 
   /* some final initialisation */
-  _giza_set_deviceOpen ();
+  Dev[id].drawn = 0;
+  Dev[id].resize = 0;
+  Dev[id].fontAngle = 0.;
   _giza_init_arrow_style ();
   _giza_init_line_style ();
   _giza_init_colour_index ();
-  /*printf("debug: init font \n");*/
 
   giza_draw_background ();
   _giza_init_colour_table ();
@@ -195,51 +226,19 @@ giza_open_device (const char *newDeviceName, const char *newPrefix)
      need to come before set_viewport_default */
   _giza_init_character_height (); /* must come BEFORE init_font */
   _giza_init_font ();
+  _giza_init_text_background();
 
   _giza_init_window (); /* call init_window BEFORE set_viewport */
   giza_set_viewport_default ();
   giza_set_line_width (1);
 
-  /*
-  printf("debug: init fill \n");
-  */
   _giza_init_fill ();
   _giza_init_band_style ();
   _giza_init_save ();
   giza_set_clipping(1);
   /*_giza_stroke();*/
-  /*
-  printf("debug: device opened \n");
-  */
-  return Dev.pgNum;
-}
-
-/**
- * Device: giza_open_device_size
- *
- * Synopsis: Similar to giza_open_device, but allows one to specify the size of the device in centimeters
- *
- * Input:
- *  -newDeviceName :- Specifies the type of device to be opened.
- *                    See below for details.
- *  -newPrefix     :- Specifies the default prefix to be used for file names.
- *  -width         :- Width for the newly opened device
- *  -height        :- Height for the newly opened device
- *  -units         :- Units in which the width/height of the device are specified
- *
- * Units:
- *  -GIZA_UNITS_DEVICE     :- device coords (i.e. pixels on bitmap devices, points on vector devices)
- *  -GIZA_UNITS_PIXELS     :- pixels
- *  -GIZA_UNITS_MM         :- mm
- *  -GIZA_UNITS_INCHES     :- inches
- *  Other values cause an error message and are treated as GIZA_UNITS_DEVICE
- */
-int
-giza_open_device_size (const char *newDeviceName, const char *newPrefix, double width, double height, int units)
-{
-  giza_set_paper_size(units,width,height);
-  _giza_set_sizeSpecified ();
-  return giza_open_device (newDeviceName, newPrefix);
+  
+  return _giza_device_id;
 }
 
 /**
@@ -253,6 +252,77 @@ giza_open_device_size_float (const char *newDeviceName, const char *newPrefix, f
   return giza_open_device_size (newDeviceName, newPrefix, (double) width, (double) height, units);
 }
 
+/**
+ * For internal book-keeping
+ * To the outside world, the device ids run from 1->Ndevices
+ * whereas within giza the referencing (id) is from 0->Ndevices-1
+ */
+int _giza_get_internal_id(int devid)
+{
+  return devid - 1;
+}
+
+/**
+ * Device: giza_get_device_id
+ *
+ * Synopsis: Returns the id of the currently selected device
+ *
+ * Output:
+ *  -devid, as returned by giza_open_device
+ *
+ * See also: giza_open_device, giza_get_device_id
+ */
+void
+giza_get_device_id (int *devid)
+{
+  *devid = _giza_device_id;
+  return;
+}
+
+/**
+ * Device: giza_select_device
+ *
+ * Synopsis: Select between the currently open devices
+ *
+ * Input:
+ *  -devid :- device id, as returned by giza_open_device
+ *
+ * See also: giza_get_device_id
+ */
+void
+giza_select_device (int devid)
+{
+  if (devid > 0 && devid <= GIZA_MAX_DEVICES) {
+    /* need to check if device is open */
+    int tmpid = _giza_get_internal_id(devid);
+    if (!Dev[tmpid].deviceOpen) 
+      {
+        _giza_error ("giza_select_device", "Invalid/closed device selected");
+
+      } else {
+
+        _giza_device_id = devid;
+        id = _giza_get_internal_id(_giza_device_id);
+
+      }
+
+    /*
+     * select between currently open windows
+     * for interactive devices 
+     */
+    switch (Dev[id].type)
+      {
+#ifdef _GIZA_HAS_XW
+      case GIZA_DEVICE_XW:
+        _giza_select_xw (id);
+        break;
+#endif
+      }
+  } else {
+    _giza_error ("giza_select_device", "Invalid device selected");
+  }
+}
+
 /**
  * Device: giza_flush_device
  *
@@ -264,24 +334,27 @@ giza_flush_device (void)
   if (!_giza_check_device_ready ("giza_flush_device"))
     return;
 
-  _giza_set_drawn ();
-
-  switch (Dev.type)
+  Dev[id].drawn = 1;
+  
+  if (!Dev[id].buf) /* do not flush if buffering is on */
     {
+     switch (Dev[id].type)
+       {
 #ifdef _GIZA_HAS_XW
-    case GIZA_DEVICE_XW:
-      _giza_flush_device_xw ();
-      break;
+       case GIZA_DEVICE_XW:
+         _giza_flush_device_xw ();
+         break;
 #endif
-    default:
-      if (!surface)
-        {
-          _giza_error ("giza_flush_device", "No device open, cannot flush");
-          return;
-        } else {
-          cairo_surface_flush(surface);
-        }
-      return;
+       default:
+         if (!Dev[id].surface)
+           {
+             _giza_error ("giza_flush_device", "No device open, cannot flush");
+             return;
+           } else {
+             cairo_surface_flush(Dev[id].surface);
+           }
+         return;
+       }
     }
   return;
 }
@@ -294,7 +367,7 @@ giza_flush_device (void)
 void
 _giza_resize_device (int width, int height)
 {
-  switch (Dev.type)
+  switch (Dev[id].type)
     {
 #ifdef _GIZA_HAS_XW
     case GIZA_DEVICE_XW:
@@ -318,28 +391,13 @@ _giza_resize_device (int width, int height)
 void
 giza_change_page (void)
 {
-    /* allow resizing of the device if nothing has been drawn */
-
-/*   if (_giza_sizeSpecified ())
-     {
-       int width,height;
-       _giza_get_specified_size(&width, &height);
-       if (width != Dev.width || height != Dev.height) {
-          printf("RESIZING %i %i \n",width,height);
-          _giza_resize_device(width, height);
-          _giza_change_page_xw();
-       } else {
-          printf("SAME SIZE %i %i \n",Dev.width,Dev.height);       
-       }
-     } else {
-       printf("NO RESIZING %i %i \n",Dev.width,Dev.height);
-     }
-*/
-
-  if (!_giza_has_drawn ()) {
+   /* allow resizing of the device if nothing has been drawn */
+  if (!Dev[id].drawn && !Dev[id].resize) {
 
     /* if nothing has changed, safe to redraw/reset the background colour */
     giza_draw_background ();
+    
+    /* do nothing */
     return;
   }
 
@@ -350,7 +408,7 @@ giza_change_page (void)
     (line style, width, colour index etc.) */
   giza_save();
 
-  switch (Dev.type)
+  switch (Dev[id].type)
     {
 #ifdef _GIZA_HAS_XW
     case GIZA_DEVICE_XW:
@@ -372,8 +430,7 @@ giza_change_page (void)
       _giza_change_page_ps ();
       break;
     case GIZA_DEVICE_NULL:
-      _giza_close_device_null ();
-      _giza_open_device_null ();
+      _giza_change_page_null ();
       break;
 #ifdef _GIZA_HAS_EPS
     case GIZA_DEVICE_EPS:
@@ -385,21 +442,29 @@ giza_change_page (void)
       return;
     }
 
-  if (_giza_get_prompting () && Dev.isInteractive)
+  if (Dev[id].resize) 
+    {
+      _giza_init_norm();
+    }
+
+  if (Dev[id].prompting && Dev[id].isInteractive && !Dev[id].resize)
     {
       _giza_newpage_prompt();
     }
 
-  Dev.pgNum++;
+  Dev[id].pgNum++;
 
   /* Reset stuff */
-  giza_set_viewport (VP.xmin,VP.xmax, VP.ymin, VP.ymax);
-  giza_set_window (Win.xmin, Win.xmax, Win.ymin, Win.ymax);
+  giza_set_viewport (Dev[id].VP.xmin,Dev[id].VP.xmax, 
+                     Dev[id].VP.ymin, Dev[id].VP.ymax);
+  giza_set_window (Dev[id].Win.xmin, Dev[id].Win.xmax,
+                   Dev[id].Win.ymin, Dev[id].Win.ymax);
 
   /* restore the previously saved settings */
   giza_restore();
 
-  _giza_reset_drawn ();
+  Dev[id].drawn = 0;
+  Dev[id].resize = 0;
   giza_draw_background ();
   giza_flush_device ();
   return;
@@ -417,15 +482,15 @@ giza_close_device (void)
   if (!_giza_check_device_ready ("giza_close_device"))
     return;
 
-  if (_giza_get_prompting () && Dev.isInteractive)
+  if (Dev[id].prompting && Dev[id].isInteractive)
     {
       _giza_newpage_prompt();
     }
 
   /* destroy the cairo context */
-  if (context) cairo_destroy(context);
+  if (Dev[id].context) cairo_destroy(Dev[id].context);
 
-  switch (Dev.type)
+  switch (Dev[id].type)
     {
 #ifdef _GIZA_HAS_XW
     case GIZA_DEVICE_XW:
@@ -458,14 +523,14 @@ giza_close_device (void)
        return;
     }
 
-  _giza_reset_deviceOpen ();
-  _giza_reset_sizeSpecified ();
+  Dev[id].deviceOpen = 0;
 
   /* Destroy the font */
   _giza_free_font ();
   _giza_free_colour_table ();
-  Dev.type = GIZA_DEVICE_IV;
-  id = id - 1;
+  Dev[id].type = GIZA_DEVICE_IV;
+  _giza_device_id = _giza_device_id - 1;
+  id = _giza_get_internal_id(_giza_device_id);
 
   return;
 }
@@ -503,7 +568,7 @@ giza_query_device (const char *querytype, char *returnval)
 
   if (!strcmp(querytype,"type"))
      {
-       if (!_giza_int_to_device(Dev.type,returnval))
+       if (!_giza_int_to_device(Dev[id].type,returnval))
          {
            ierr = 1;
          }
@@ -511,7 +576,7 @@ giza_query_device (const char *querytype, char *returnval)
   /* Query whether or not device has cursor */
   else if (!strcmp(querytype,"cursor"))
     {
-      if (Dev.isInteractive)
+      if (Dev[id].isInteractive)
         {
           strncpy(returnval,"YES",sizeof(returnval)-1);
         }
@@ -523,7 +588,7 @@ giza_query_device (const char *querytype, char *returnval)
   /* Query whether or not device is hard copy or not */
   else if (!strcmp(querytype,"hardcopy"))
     {
-      if (Dev.isInteractive)
+      if (Dev[id].isInteractive)
         {
           strncpy(returnval,"NO",sizeof(returnval)-1);
         }
@@ -535,7 +600,7 @@ giza_query_device (const char *querytype, char *returnval)
   /* Query whether or not device is open or not */
   else if (!strcmp(querytype,"state"))
     {
-       if (_giza_get_deviceOpen())
+       if (Dev[id].deviceOpen)
          {
             strncpy(returnval,"OPEN",sizeof(returnval)-1);         
          }
@@ -552,13 +617,13 @@ giza_query_device (const char *querytype, char *returnval)
   /* Query current device name */
   else if (!strcmp(querytype,"device"))
     {
-       strncpy(returnval,Dev.prefix,sizeof(returnval)-1);
+       strncpy(returnval,Dev[id].prefix,sizeof(returnval)-1);
     }
   /* Query current device/type */
   else if (!strcmp(querytype,"dev/type"))
     {
-       strncpy(returnval,Dev.prefix,sizeof(returnval)-1);
-       if (!_giza_int_to_device(Dev.type,devType))
+       strncpy(returnval,Dev[id].prefix,sizeof(returnval)-1);
+       if (!_giza_int_to_device(Dev[id].type,devType))
          {
            ierr = 1;
            strncat(returnval,devType,4*sizeof(char));
@@ -567,9 +632,9 @@ giza_query_device (const char *querytype, char *returnval)
   /* Query current filename (as entered by user) */
   else if (!strcmp(querytype,"file"))
     {
-       if (!Dev.isInteractive)
+       if (!Dev[id].isInteractive)
          {
-           strncpy(returnval,Dev.prefix,sizeof(returnval)-1);
+           strncpy(returnval,Dev[id].prefix,sizeof(returnval)-1);
          }
     }
   returnval[sizeof(returnval)-1] = '\0'; /* make sure string is null-terminated */
@@ -602,7 +667,7 @@ _giza_get_key_press (int mode, int moveCurs, int nanc, const double *xanch, cons
   if (!_giza_check_device_ready ("_giza_get_key_press"))
     return 1;
 
-  switch (Dev.type)
+  switch (Dev[id].type)
     {
     case GIZA_DEVICE_NULL:
     case GIZA_DEVICE_PDF:
@@ -806,23 +871,23 @@ giza_print_device_list (void)
 void
 _giza_init_device_list (char **deviceList)
 {
-  *deviceList = malloc (500 * sizeof(char)); /* be CAREFUL here to make sure the string is big enough */
+  *deviceList = malloc (1000 * sizeof(char)); /* be CAREFUL here to make sure the string is big enough */
 
   *deviceList[0] = '\0';
 #ifdef _GIZA_HAS_XW
   strcat (*deviceList, "Interactive devices:\n\t/xw\t(X Window)\n");
 #endif
   strcat (*deviceList, "Non-interactive file formats:\n");
-  strcat (*deviceList, "\t/png\t(Portable network graphics file)\n");
-  strcat (*deviceList, "\t/svg\t(Scalable vector graphics file)\n");
+  strcat (*deviceList, "\t/png or file.png   (Portable network graphics file)\n");
+  strcat (*deviceList, "\t/svg or file.svg   (Scalable vector graphics file)\n");
 #ifdef _GIZA_HAS_EPS
-  strcat (*deviceList, "\t/eps\t(Encapsulated Postscript, one file per page)\n");
+  strcat (*deviceList, "\t/eps or file.eps   (Encapsulated Postscript, one file per page)\n");
 #endif
-  strcat (*deviceList, "\t/pdf\t(Portable document format file)\n");
-  strcat (*deviceList, "\t/vpdf\t(Portable document format file portrait)\n");
-  strcat (*deviceList, "\t/ps\t(Postscript file, multiple pages per file)\n");
-  strcat (*deviceList, "\t/vps\t(Postscript file portrait, multiple pages per file)\n");
-  strcat (*deviceList, "\t/null\t(Null device)\n");
+  strcat (*deviceList, "\t/pdf or file.pdf   (Portable document format file)\n");
+  strcat (*deviceList, "\t/vpdf              (Portable document format file portrait)\n");
+  strcat (*deviceList, "\t/ps  or file.ps    (Postscript file, multiple pages per file)\n");
+  strcat (*deviceList, "\t/vps               (Postscript file portrait, multiple pages per file)\n");
+  strcat (*deviceList, "\t/null              (Null device)\n");
 }
 
 /**
@@ -848,7 +913,7 @@ _giza_init_norm (void)
 
   double xx,yy,x0,y0;
 
-  switch (Dev.type)
+  switch (Dev[id].type)
     {
 #ifdef _GIZA_HAS_XW
     /*
@@ -874,11 +939,11 @@ _giza_init_norm (void)
      *      to normalised device coords to avoid clipping at the edge
      */
 
-      xx = (double) Dev.width - 2.*GIZA_DEFAULT_MARGIN;
-      yy = 2.*GIZA_DEFAULT_MARGIN - (double) Dev.height;
+      xx = (double) Dev[id].width - 2.*GIZA_DEFAULT_MARGIN;
+      yy = 2.*GIZA_DEFAULT_MARGIN - (double) Dev[id].height;
       x0 = GIZA_DEFAULT_MARGIN;
-      y0 = (double) Dev.height - GIZA_DEFAULT_MARGIN;
-      cairo_matrix_init (&(Win.normCoords), xx, 0, 0, yy, x0, y0);
+      y0 = (double) Dev[id].height - GIZA_DEFAULT_MARGIN;
+      cairo_matrix_init (&(Dev[id].Win.normCoords), xx, 0, 0, yy, x0, y0);
       _giza_set_trans (GIZA_TRANS_NORM);
       break;
     }
@@ -893,7 +958,7 @@ _giza_expand_clipping (void)
 {
     if (!_giza_check_device_ready ("_giza_expand_clipping"))
     return;
-  switch (Dev.type)
+  switch (Dev[id].type)
     {
 #ifdef _GIZA_HAS_XW
     case GIZA_DEVICE_XW:
@@ -902,20 +967,20 @@ _giza_expand_clipping (void)
 #endif
     default:
       _giza_set_trans (GIZA_TRANS_IDEN);
-      cairo_reset_clip (context);
-      cairo_rectangle (context, 0, 0, Dev.width, Dev.height);
-      cairo_clip (context);
+      cairo_reset_clip (Dev[id].context);
+      cairo_rectangle (Dev[id].context, 0, 0, Dev[id].width, Dev[id].height);
+      cairo_clip (Dev[id].context);
       break;
     }
 }
 
 /**
- * Allocates the array for Dev.prefix and sets it to prefix
+ * Allocates the array for Dev[id].prefix and sets it to prefix
  */
 static void
 _giza_set_prefix (const char *prefix)
 {
-  strncpy (Dev.prefix, prefix, sizeof(Dev.prefix));
+  strncpy (Dev[id].prefix, prefix, sizeof(Dev[id].prefix));
 }
 
 /*
@@ -927,7 +992,7 @@ _giza_init_band (int mode)
   if (mode == 0) return 0;
 
   int success = 1;
-  switch (Dev.type)
+  switch (Dev[id].type)
     {
 #ifdef _GIZA_HAS_XW
       case GIZA_DEVICE_XW:
@@ -939,7 +1004,7 @@ _giza_init_band (int mode)
 	break;
     }
   _giza_set_line_style (Band.ls, Band.box);
-  double lwDevice = Band.lw * Dev.deviceUnitsPermm * 0.25;
+  double lwDevice = Band.lw * Dev[id].deviceUnitsPermm * 0.25;
   cairo_set_line_width (Band.box, lwDevice);
 
   return success;
@@ -998,8 +1063,6 @@ void _giza_get_filename_for_device (char *filename, char *prefix, int pgNum, cha
   _giza_trim(prefixtrim);
   _giza_trim(ext);
 
-  /*printf(" got prefix = \"%s\" extension=\"%s\" \n",prefixtrim,ext);*/
-
   if (!strstr(lprefix,lextens)) {
   /* Add the device extension if prefix string does not already contain it */
      if (pgNum == 0 && lastpage != 0) {
