@@ -33,8 +33,9 @@
 module asciiutils
  implicit none
  public :: read_asciifile,get_ncolumns,ncolumnsline,safename,basename,cstring
- public :: string_replace, string_delete, nheaderlines
+ public :: string_replace, string_delete, nheaderlines, string_sub
  public :: ucase,lcase
+ public :: get_line_containing
 
  private
 
@@ -466,6 +467,28 @@ subroutine string_replace(string,skey,sreplacewith)
 
 end subroutine string_replace
 
+!---------------------------------------------------------------------------
+!
+! subroutine to replace a specified section of a string with a
+! replacement string, possibly of differing length
+!
+!---------------------------------------------------------------------------
+subroutine string_sub(string,i1,i2,sreplacewith)
+ implicit none
+ character(len=*), intent(inout) :: string
+ integer, intent(in)             :: i1,i2
+ character(len=*), intent(in)    :: sreplacewith
+ character(len=len(string))      :: oldstring
+
+ oldstring = string
+ if (i2 < len_trim(string)) then
+    string = oldstring(1:i1-1)//sreplacewith//oldstring(i2+1:len_trim(oldstring))
+ else
+    string = oldstring(1:i1-1)//sreplacewith
+ endif
+
+end subroutine string_sub
+
 !---------------------------------------------------------------------------
 !
 ! subroutine to delete all matching occurrences of key from string
@@ -528,4 +551,26 @@ function lcase(string)
 
 end function lcase
 
+!---------------------------------------------------------------------------
+!
+! Converts a string to lower case
+!
+!---------------------------------------------------------------------------
+integer function get_line_containing(filename,string)
+ character(len=*), intent(in) :: filename, string
+ character(len=130) :: line
+ integer :: lu,i,ierr
+ 
+ get_line_containing = 0
+ open(newunit=lu,file=filename,status='old',iostat=ierr)
+ i = 0
+ do while(ierr.eq.0)
+    i = i + 1
+    read(lu,"(a)",iostat=ierr) line
+    if (index(line,string).ne.0) get_line_containing = i
+ enddo
+ close(lu)
+ 
+end function get_line_containing
+
 end module asciiutils
