@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2013 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2014 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -79,6 +79,8 @@ module exact
   character(len=120), dimension(10) :: funcstring
   !--Roche potential
   real :: semi,ecc,mprim,msec
+  !--C-shock
+  real :: machs,macha
   !
   !--sort these into a namelist for input/output
   !
@@ -92,7 +94,7 @@ module exact
        rho_L, rho_R, pr_L, pr_R, v_L, v_R,ishk,hfact, &
        iprofile,Msphere,rsoft,icolpoten,icolfgrav,Mstar,Rtorus,distortion, &
        Mring,Rring,viscnu,nfunc,funcstring,cs,Kdrag,rhozero,rdust_to_gas, &
-       semi,ecc,mprim,msec,ixcolfile,iycolfile,xshock
+       semi,ecc,mprim,msec,ixcolfile,iycolfile,xshock,totmass,machs,macha
 
   public :: defaults_set_exact,submenu_exact,options_exact,read_exactparams
   public :: exact_solution
@@ -166,6 +168,9 @@ contains
     ecc   = 0.
     mprim = 1.
     msec  = 1.
+!   C-shock
+    machs = 50. ! sonic Mach number
+    macha = 5.  ! Alfvenic Mach number
 
 !   arbitrary function
     nfunc = 1
@@ -216,8 +221,9 @@ contains
            '12) ring spreading ',/, &
            '13) special relativistic shock tube', /, &
            '14) dusty waves', /, &
-           '15) Roche lobes/potential ')
-    call prompt('enter exact solution to plot',iexact,0,15)
+           '15) Roche lobes/potential ',/, &
+           '16) C-shock ')
+    call prompt('enter exact solution to plot',iexact,0,16)
     print "(a,i2)",'plotting exact solution number ',iexact
     !
     !--enter parameters for various exact solutions
@@ -320,6 +326,7 @@ contains
        call prompt('enter blast wave energy E ',esedov,0.0)
     case(5)
        call prompt('enter polytropic k ',polyk)
+       call prompt('enter total mass ',totmass)
     case(6)
        print "(a)",' toy star: '
        call read_exactparams(iexact,trim(rootname(1)),ierr)
@@ -410,6 +417,9 @@ contains
        call prompt('enter semi-major axis of binary',semi,0.)
        call prompt('enter mass of primary star ',mprim,0.)
        call prompt('enter mass of secondary star ',msec,0.,mprim)
+    case(16)
+       call prompt('enter sonic Mach number',machs,0.)
+       call prompt('enter Alfvenic Mach number ',macha,0.)
     end select
 
     return
@@ -457,13 +467,13 @@ contains
     use prompting,      only:prompt
     use exactfunction,  only:check_function
     use filenames,      only:fileprefix
-    use asciiutils,     only:read_asciifile
+    use asciiutils,     only:read_asciifile,get_line_containing
     implicit none
     integer, intent(in) :: iexact
     character(len=*), intent(in) :: rootname
     integer, intent(out) :: ierr
 
-    integer :: idash,nf,i,j,idrag,idum
+    integer :: idash,nf,i,j,idrag,idum,linenum
     character(len=len_trim(rootname)+8) :: filename
 
     idash = index(rootname,'_')
@@ -600,9 +610,10 @@ contains
        !--dustywave parameters from ndspmhd input file
        !
        filename = trim(rootname(1:idash-1))//'.in'
+       linenum = get_line_containing(filename,'Kdrag')
        open(unit=19,file=filename,status='old',iostat=ierr)
        if (ierr.eq.0) then
-          do i=1,23
+          do i=1,linenum-1
              read(19,*,iostat=ierr)
           enddo
           if (ierr.eq.0) then
@@ -651,7 +662,7 @@ contains
                             ndim,ndimV,time,xmin,xmax,gamma,xplot,yplot, &
                             pmassmin,pmassmax,npart,imarker,unitsx,unitsy,irescale,iaxisy)
     use labels,          only:ix,irad,iBfirst,ivx,irho,ike,iutherm,ih,ipr,iJfirst,&
-                              irhorestframe,is_coord
+                              irhorestframe,is_coord,ideltav,idustfrac
     use filenames,       only:ifileopen,rootname
     use asciiutils,      only:string_replace
     use prompting,       only:prompt
@@ -672,6 +683,7 @@ contains
     use dustywaves,      only:exact_dustywave
     use rochelobe,       only:exact_rochelobe
     use gresho,          only:exact_gresho
+    use Cshock,          only:exact_Cshock
     use transforms,      only:transform,transform_inverse
     use plotlib,         only:plot_qci,plot_qls,plot_sci,plot_sls,plot_line
     implicit none
@@ -791,6 +803,12 @@ contains
           elseif (iploty.eq.iutherm) then
               call exact_shock(4,timei,gamma,rho_L,rho_R,pr_L,pr_R,v_L,v_R, &
                               rdust_to_gas,xexact,yexact,ierr)
+          elseif (iploty.eq.ideltav) then
+              call exact_shock(5,timei,gamma,rho_L,rho_R,pr_L,pr_R,v_L,v_R, &
+                              rdust_to_gas,xexact,yexact,ierr)
+          elseif (iploty.eq.idustfrac) then
+              call exact_shock(6,timei,gamma,rho_L,rho_R,pr_L,pr_R,v_L,v_R, &
+                              rdust_to_gas,xexact,yexact,ierr)
           endif
        endif
 
@@ -808,13 +826,13 @@ contains
           elseif (iploty.eq.ivx .and. igeom.eq.3) then
              call exact_sedov(5,timei,gamma,rhosedov,esedov,xmax,xexact,yexact,ierr)
           endif
-       !elseif (igeom.le.1 .and. is_coord(iplotx,ndim) .and. is_coord(iploty,ndim)) then
-       !   call exact_sedov(0,timei,gamma,rhosedov,esedov,xmax,xexact,yexact,ierr)
+       elseif (igeom.le.1 .and. is_coord(iplotx,ndim) .and. is_coord(iploty,ndim)) then
+          call exact_sedov(0,timei,gamma,rhosedov,esedov,xmax,xexact,yexact,ierr)
        endif
 
     case(5)! polytrope
        if (iploty.eq.irho .and. (iplotx.eq.irad .or.(igeom.eq.3 .and. iplotx.eq.ix(1)))) then
-          call exact_polytrope(gamma,polyk,xexact,yexact,iexactpts,ierr)
+          call exact_polytrope(gamma,polyk,totmass,xexact,yexact,iexactpts,ierr)
        endif
 
     case(6)! toy star
@@ -1035,6 +1053,14 @@ contains
        if (igeom.eq.1 .and. ndim.ge.2 .and. iplotx.eq.ix(1) .and. iploty.eq.ix(2)) then
           call exact_rochelobe(timei,semi,mprim,msec,xexact,yexact,ierr)
        endif
+    case(16) ! C-shock
+       if (ndim.ge.1 .and. iplotx.eq.ix(1) .and. igeom.le.1) then
+          if (iploty.eq.irho) then
+             call exact_Cshock(1,timei,gamma,machs,macha,xmin,xmax,xexact,yexact,ierr)
+          elseif (iploty.eq.iBfirst+1 .and. iBfirst.gt.0) then
+             call exact_Cshock(2,timei,gamma,machs,macha,xmin,xmax,xexact,yexact,ierr)
+          endif
+       endif
     end select
 
     !----------------------------------------------------------
