@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2013 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2014 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -314,7 +314,7 @@ ncolumns = ncol_max
 ndim = ndim_max
 ndimV = ndimV_max
 
-if (iformat.eq.5 .and. lenvironment('NSPLASH_TWOFLUID')) then
+if (iformat.eq.5 .and. .not.lenvironment('NSPLASH_ONEFLUID_RAW')) then
    call fake_twofluids
    iformat = 1
 endif
@@ -333,7 +333,7 @@ return
 contains
 
 subroutine fake_twofluids
- use labels, only:idustfrac,irho,ix,ih,iutherm,ipmass,ivx,ideltav
+ use labels, only:idustfrac,irho,ix,ih,ipmass,ivx,ideltav
  implicit none
  integer :: ndust,jdust
  real    :: rhodust,rhogas,rhotot,dustfraci,pmassgas,pmassdust,pmassj
@@ -347,6 +347,8 @@ subroutine fake_twofluids
           call alloc(ntoti + npartoftype(1,i),maxstep,maxcol,mixedtypes=.true.)
        endif
        ndust = 0
+       !--zero the properties of newly created dust particles
+       dat(ntoti+1:ntoti+npartoftype(1,i),:,i) = 0.
        do j=1,ntoti
           if (iamtype(j,i).eq.1) then
              ndust = ndust + 1 ! one dust particle for every gas particle
@@ -358,6 +360,7 @@ subroutine fake_twofluids
              dat(j,irho,i) = rhogas
              !--copy x, smoothing length onto dust particle
              jdust = ntoti + ndust
+             
              !--fill in dust properties
              if (ndim.gt.0) dat(jdust,ix(1:ndim),i) = dat(j,ix(1:ndim),i)
              if (ih.gt.0)   dat(jdust,ih,i)         = dat(j,ih,i)
@@ -385,6 +388,7 @@ subroutine fake_twofluids
           endif
        enddo
        print "(a,i10,a)",' Creating ',ndust,' fictional dust particles...'
+       print "(a)",' (set NSPLASH_BARYCENTRIC=yes to plot barycentric values)'
        npartoftype(2,i) = npartoftype(2,i) + ndust
     enddo
  else
@@ -504,7 +508,7 @@ subroutine set_labels
     label(icol) = 'dust fraction'
     idustfrac = icol
     iamvec(icol+1:icol+ndimV) = icol + 1
-    labelvec(icol+1:icol+ndimV) = 'deltav'
+    labelvec(icol+1:icol+ndimV) = '\Deltav'
     ideltav = icol + 1
     icol = icol + ndimV
  elseif (iformat.gt.2) then
